import {ScrollView, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import style from './lineChart.module.scss'
import {formatMinute} from "@/utils/time";

export interface lineData {
  time: string
  value: number
}

interface Props {
  data: lineData[]
}

const height = 180
const LineChart: FC<Props> = ({data}) => {
  const [maxHeight, setMaxHeight] = useState<lineData>({time: '', value: 0})
  const [lineChartList, setLineChartList] = useState(data)

  useEffect(() => {
    setLineChartList(data)
    setMaxHeight(data.reduce((pre, cur) => {
      if (cur.value > pre.value) {
        return cur
      }
      return pre
    }, maxHeight))
  }, [data])

  return (
    <>
      <ScrollView scrollX={!!maxHeight.value}>
        <View style={{marginBottom: '30px'}}>{maxHeight.time}日最努力，学习了{formatMinute(maxHeight.value)}</View>

        <View className={style.lineChart}>
          {!maxHeight.value && <View className={style.empty}>暂无数据</View>}
          {
            !!maxHeight.value && lineChartList.map(d => <View key={d.time}>
              <View className={style.columnBox} style={{width: "100px"}}>
                <View className={style.line}
                      style={{height: height - 10 - (d.value / maxHeight.value * height) + "px"}}></View>
                <View>{formatMinute(d.value)}</View>
                <View className={style.column} style={{height: d.value / maxHeight.value * height + "px"}}> </View>
                <View>{d.time}</View>
              </View>
            </View>)
          }
        </View>
      </ScrollView>
    </>
  )
}

export default LineChart
