import {FC, useEffect, useState} from "react";
import {useDidShow, useReachBottom} from "@tarojs/taro";
import {View} from "@tarojs/components";
import {Courses, CoursesKey, publicApi} from "@/api/public";
import VideoCover from "@/components/videoCover/videoCover";
import styles from '../index.module.scss'
import {formatMinute} from "@/utils/time";
import {userApi} from "@/api";
import Empty from "@/components/empty/empty";
import eventsIndex from "@/hooks/eventsIndex";

interface Props {
  categoryKey: CoursesKey
  ready: boolean
}

export const VideoList: FC<Props> = ({categoryKey, ready}) => {
  const [data, setData] = useState<Courses>({
    is_finished: [],
    is_required: [],
    is_not_finished: [],
    is_not_required: []
  })
  const [page, setPage] = useState(1)
  const [records, setRecords] = useState<LearnRecord[]>([])

  function screen(oldData: Curriculum[], data: Curriculum[]): Curriculum[] {
    return data.reduce((pre, cur) => {
      const index = pre.findIndex(d => d.id === cur.id)
      if (index === -1) {
        pre.push(cur)
      } else {
        pre.splice(index, 1, cur)
      }
      return pre
    }, oldData)
  }

  async function getData() {
    try {
      const res = await publicApi.course({page: page, pageSize: 10})

      const old: Courses = JSON.parse(JSON.stringify(data))
      setData({
        is_finished: screen(old.is_finished, res.is_finished || []),
        is_required: screen(old.is_required, res.is_required || []),
        is_not_finished: screen(old.is_not_finished, res.is_not_finished || []),
        is_not_required: screen(old.is_not_required, res.is_not_required || []),
      })
    } catch (e) {
    }
  }

  async function getRecords() {
    try {
      const {user_course_records} = await userApi.learningRecord()
      setRecords(user_course_records)
    } catch (e) {
    }
  }


  function rateOfLearning(id: number, class_hour: number): JSX.Element {
    switch (categoryKey) {
      case "is_required":
      case "is_not_required":
      case "is_not_finished":
        const find = records.find(d => d?.course_id === id)
        if (find) {
          if (class_hour === find.finished_count) {
            return <View>已完成</View>
          }
          return (<View>{`共${class_hour}节/已学${find.finished_count}节`}</View>)
        }
        return (<View>{`共${class_hour}节/已学0节`}</View>)
      case "is_finished":
        return <View>已完成</View>
    }
  }

  useReachBottom(() => {
    setPage(page + 1)
  })

  eventsIndex.on(({id}) => {
    if (id == null) return;
    for (const [index, notFinished] of data.is_not_finished.entries()) {
      if (notFinished.id === id) {
        data.is_finished.push(notFinished)
        data.is_not_finished.splice(index, 1)
        return
      }
    }
  })

  useDidShow(() => {
    if (ready) {
      getData().then()
      getRecords().then()
    }
  })

  useEffect(() => {
    if (ready) {
      getData().then()
      getRecords().then()
    }
  }, [page, ready])
  return (
    <View className={'py-2 flex justify-between flex-wrap ' + styles.videoListBox}>
      {data?.[categoryKey]?.length ? data?.[categoryKey]?.map(c =>
        <VideoCover
          thumb={c.thumb}
          title={c.title}
          id={c.id}
          depId={c.id}
          key={c.id}
          time={formatMinute(c.course_duration)}
          content={rateOfLearning(c.id, c.class_hour)}
        />) : <Empty name='暂无数据'/>}
    </View>
  )
}

